==> aws-sdk-cpp-1.9.365-2-x86_64.pkg.tar.zst: usr/include/aws/frauddetector/model/CancelBatchImportJobRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/frauddetector/FraudDetector_EXPORTS.h>
#include <aws/frauddetector/FraudDetectorRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace FraudDetector
{
namespace Model
{

  /**
   */
  class AWS_FRAUDDETECTOR_API CancelBatchImportJobRequest : public FraudDetectorRequest
  {
  public:
    CancelBatchImportJobRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "CancelBatchImportJob"; }

    Aws::String SerializePayload() const override;

    Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;


    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline const Aws::String& GetJobId() const{ return m_jobId; }

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline bool JobIdHasBeenSet() const { return m_jobIdHasBeenSet; }

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline void SetJobId(const Aws::String& value) { m_jobIdHasBeenSet = true; m_jobId = value; }

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline void SetJobId(Aws::String&& value) { m_jobIdHasBeenSet = true; m_jobId = std::move(value); }

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline void SetJobId(const char* value) { m_jobIdHasBeenSet = true; m_jobId.assign(value); }

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline CancelBatchImportJobRequest& WithJobId(const Aws::String& value) { SetJobId(value); return *this;}

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline CancelBatchImportJobRequest& WithJobId(Aws::String&& value) { SetJobId(std::move(value)); return *this;}

    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline CancelBatchImportJobRequest& WithJobId(const char* value) { SetJobId(value); return *this;}

  private:

    Aws::String m_jobId;
    bool m_jobIdHasBeenSet = false;
  };

} // namespace Model
} // namespace FraudDetector
} // namespace Aws

==> aws-sdk-cpp-1.11.476-1-x86_64.pkg.tar.zst: usr/include/aws/frauddetector/model/CancelBatchImportJobRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/frauddetector/FraudDetector_EXPORTS.h>
#include <aws/frauddetector/FraudDetectorRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace FraudDetector
{
namespace Model
{

  /**
   */
  class CancelBatchImportJobRequest : public FraudDetectorRequest
  {
  public:
    AWS_FRAUDDETECTOR_API CancelBatchImportJobRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "CancelBatchImportJob"; }

    AWS_FRAUDDETECTOR_API Aws::String SerializePayload() const override;

    AWS_FRAUDDETECTOR_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;


    ///@{
    /**
     * <p> The ID of an in-progress batch import job to cancel. </p> <p>Amazon Fraud
     * Detector will throw an error if the batch import job is in <code>FAILED</code>,
     * <code>CANCELED</code>, or <code>COMPLETED</code> state.</p>
     */
    inline const Aws::String& GetJobId() const{ return m_jobId; }
    inline bool JobIdHasBeenSet() const { return m_jobIdHasBeenSet; }
    inline void SetJobId(const Aws::String& value) { m_jobIdHasBeenSet = true; m_jobId = value; }
    inline void SetJobId(Aws::String&& value) { m_jobIdHasBeenSet = true; m_jobId = std::move(value); }
    inline void SetJobId(const char* value) { m_jobIdHasBeenSet = true; m_jobId.assign(value); }
    inline CancelBatchImportJobRequest& WithJobId(const Aws::String& value) { SetJobId(value); return *this;}
    inline CancelBatchImportJobRequest& WithJobId(Aws::String&& value) { SetJobId(std::move(value)); return *this;}
    inline CancelBatchImportJobRequest& WithJobId(const char* value) { SetJobId(value); return *this;}
    ///@}
  private:

    Aws::String m_jobId;
    bool m_jobIdHasBeenSet = false;
  };

} // namespace Model
} // namespace FraudDetector
} // namespace Aws
